@@ -9,7 +9,7 @@ from woodwork.logical_types import (
     BooleanNullable,
     Categorical,
     Datetime,
-    Ordinal
+    Ordinal,
 )
 
 from featuretools.primitives.base import TransformPrimitive
@@ -38,9 +38,10 @@ class Age(TransformPrimitive):
         >>> age(input_ages, time=reference_date).tolist()
         [19.013698630136986, 35.61643835616438, 21.221917808219178]
     """
+
     name = "age"
-    input_types = [ColumnSchema(logical_type=Datetime, semantic_tags={'date_of_birth'})]
-    return_type = ColumnSchema(logical_type=AgeFractional, semantic_tags={'numeric'})
+    input_types = [ColumnSchema(logical_type=Datetime, semantic_tags={"date_of_birth"})]
+    return_type = ColumnSchema(logical_type=AgeFractional, semantic_tags={"numeric"})
     uses_calc_time = True
     compatibility = [Library.PANDAS, Library.DASK]
     description_template = "the age from {}"
@@ -48,6 +49,7 @@ class Age(TransformPrimitive):
     def get_function(self):
         def age(x, time=None):
             return (time - x).dt.days / 365
+
         return age
 
 
@@ -83,22 +85,26 @@ class DateToHoliday(TransformPrimitive):
         >>> date_to_holiday_canada(dates).tolist()
         ['Canada Day', nan, 'Boxing Day', 'Labour Day']
     """
+
     name = "date_to_holiday"
     input_types = [ColumnSchema(logical_type=Datetime)]
-    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={'category'})
+    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={"category"})
 
-    def __init__(self, country='US'):
+    def __init__(self, country="US"):
         self.country = country
         self.holidayUtil = HolidayUtil(country)
 
     def get_function(self):
         def date_to_holiday(x):
             holiday_df = self.holidayUtil.to_df()
-            df = pd.DataFrame({'date': x})
-            df.date = df.date.dt.normalize().astype('datetime64')
+            df = pd.DataFrame({"date": x})
+            df.date = df.date.dt.normalize().astype("datetime64")
 
-            df = df.merge(holiday_df, how='left', left_on='date', right_on='holiday_date')
+            df = df.merge(
+                holiday_df, how="left", left_on="date", right_on="holiday_date"
+            )
             return df.names.values
+
         return date_to_holiday
 
 
@@ -114,15 +120,19 @@ class Day(TransformPrimitive):
         >>> day(dates).tolist()
         [1, 3, 31]
     """
+
     name = "day"
     input_types = [ColumnSchema(logical_type=Datetime)]
-    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(1, 32))), semantic_tags={'category'})
+    return_type = ColumnSchema(
+        logical_type=Ordinal(order=list(range(1, 32))), semantic_tags={"category"}
+    )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the day of the month of {}"
 
     def get_function(self):
         def day(vals):
             return vals.dt.day
+
         return day
 
 
@@ -166,9 +176,10 @@ class DistanceToHoliday(TransformPrimitive):
         >>> distance_to_holiday(dates).tolist()
         [143, -10, -70, 144]
     """
+
     name = "distance_to_holiday"
     input_types = [ColumnSchema(logical_type=Datetime)]
-    return_type = ColumnSchema(semantic_tags={'numeric'})
+    return_type = ColumnSchema(semantic_tags={"numeric"})
     default_value = 0
 
     def __init__(self, holiday="New Year's Day", country="US"):
@@ -178,7 +189,7 @@ class DistanceToHoliday(TransformPrimitive):
 
         available_holidays = list(set(self.holidayUtil.federal_holidays.values()))
         if self.holiday not in available_holidays:
-            error = 'must be one of the available holidays:\n%s' % available_holidays
+            error = "must be one of the available holidays:\n%s" % available_holidays
             raise ValueError(error)
 
     def get_function(self):
@@ -186,18 +197,25 @@ class DistanceToHoliday(TransformPrimitive):
             holiday_df = self.holidayUtil.to_df()
             holiday_df = holiday_df[holiday_df.names == self.holiday]
 
-            df = pd.DataFrame({'date': x})
-            df['x_index'] = df.index  # store original index as a column
+            df = pd.DataFrame({"date": x})
+            df["x_index"] = df.index  # store original index as a column
             df = df.dropna()
-            df = df.sort_values('date')
+            df = df.sort_values("date")
             df.date = df.date.dt.normalize()
 
-            matches = pd.merge_asof(df, holiday_df, left_on='date', right_on='holiday_date',
-                                    direction='nearest', tolerance=pd.Timedelta('365d'))
-            matches = matches.set_index('x_index')
-            matches['days_diff'] = (matches.holiday_date - matches.date).dt.days
+            matches = pd.merge_asof(
+                df,
+                holiday_df,
+                left_on="date",
+                right_on="holiday_date",
+                direction="nearest",
+                tolerance=pd.Timedelta("365d"),
+            )
+            matches = matches.set_index("x_index")
+            matches["days_diff"] = (matches.holiday_date - matches.date).dt.days
 
             return matches.days_diff.reindex_like(x)
+
         return distance_to_holiday
 
 
@@ -213,15 +231,19 @@ class Hour(TransformPrimitive):
         >>> hour(dates).tolist()
         [0, 11, 19]
     """
+
     name = "hour"
     input_types = [ColumnSchema(logical_type=Datetime)]
-    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(24))), semantic_tags={'category'})
+    return_type = ColumnSchema(
+        logical_type=Ordinal(order=list(range(24))), semantic_tags={"category"}
+    )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
-    description_template = 'the hour value of {}'
+    description_template = "the hour value of {}"
 
     def get_function(self):
         def hour(vals):
             return vals.dt.hour
+
         return hour
 
 
@@ -237,6 +259,7 @@ class IsWeekend(TransformPrimitive):
         >>> is_weekend(dates).tolist()
         [False, False, True]
     """
+
     name = "is_weekend"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(logical_type=BooleanNullable)
@@ -246,6 +269,7 @@ class IsWeekend(TransformPrimitive):
     def get_function(self):
         def is_weekend(vals):
             return vals.dt.weekday > 4
+
         return is_weekend
 
 
@@ -261,15 +285,19 @@ class Minute(TransformPrimitive):
         >>> minute(dates).tolist()
         [0, 10, 45]
     """
+
     name = "minute"
     input_types = [ColumnSchema(logical_type=Datetime)]
-    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(60))), semantic_tags={'category'})
+    return_type = ColumnSchema(
+        logical_type=Ordinal(order=list(range(60))), semantic_tags={"category"}
+    )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the minutes value of {}"
 
     def get_function(self):
         def minute(vals):
             return vals.dt.minute
+
         return minute
 
 
@@ -285,15 +313,19 @@ class Month(TransformPrimitive):
         >>> month(dates).tolist()
         [3, 6, 11]
     """
+
     name = "month"
     input_types = [ColumnSchema(logical_type=Datetime)]
-    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(1, 13))), semantic_tags={'category'})
+    return_type = ColumnSchema(
+        logical_type=Ordinal(order=list(range(1, 13))), semantic_tags={"category"}
+    )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the month of {}"
 
     def get_function(self):
         def month(vals):
             return vals.dt.month
+
         return month
 
 
@@ -309,15 +341,19 @@ class Second(TransformPrimitive):
         >>> second(dates).tolist()
         [0, 50, 15]
     """
+
     name = "second"
     input_types = [ColumnSchema(logical_type=Datetime)]
-    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(60))), semantic_tags={'category'})
+    return_type = ColumnSchema(
+        logical_type=Ordinal(order=list(range(60))), semantic_tags={"category"}
+    )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the seconds value of {}"
 
     def get_function(self):
         def second(vals):
             return vals.dt.second
+
         return second
 
 
@@ -352,9 +388,10 @@ class TimeSince(TransformPrimitive):
         >>> list(map(lambda x: int(round(x)), values))
         [-1000, -1000000000, -120000000000]
     """
-    name = 'time_since'
+
+    name = "time_since"
     input_types = [ColumnSchema(logical_type=Datetime)]
-    return_type = ColumnSchema(semantic_tags={'numeric'})
+    return_type = ColumnSchema(semantic_tags={"numeric"})
     uses_calc_time = True
     compatibility = [Library.PANDAS, Library.DASK]
     description_template = "the time from {} to the cutoff time"
@@ -365,6 +402,7 @@ class TimeSince(TransformPrimitive):
     def get_function(self):
         def pd_time_since(array, time):
             return convert_time_units((time - array).dt.total_seconds(), self.unit)
+
         return pd_time_since
 
 
@@ -392,9 +430,10 @@ class TimeSincePrevious(TransformPrimitive):
         >>> time_since_previous(dates).tolist()
         [nan, 120.0, 60.0, -30.0, 450.0]
     """
+
     name = "time_since_previous"
-    input_types = [ColumnSchema(logical_type=Datetime, semantic_tags={'time_index'})]
-    return_type = ColumnSchema(semantic_tags={'numeric'})
+    input_types = [ColumnSchema(logical_type=Datetime, semantic_tags={"time_index"})]
+    return_type = ColumnSchema(semantic_tags={"numeric"})
     description_template = "the time since the previous instance of {}"
 
     def __init__(self, unit="seconds"):
@@ -402,7 +441,10 @@ class TimeSincePrevious(TransformPrimitive):
 
     def get_function(self):
         def pd_diff(values):
-            return convert_time_units(values.diff().apply(lambda x: x.total_seconds()), self.unit)
+            return convert_time_units(
+                values.diff().apply(lambda x: x.total_seconds()), self.unit
+            )
+
         return pd_diff
 
 
@@ -422,21 +464,27 @@ class Week(TransformPrimitive):
         >>> week = Week()
         >>> week(dates).tolist()
         [1, 25, 48]
-        """
+    """
+
     name = "week"
     input_types = [ColumnSchema(logical_type=Datetime)]
-    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(1, 54))), semantic_tags={'category'})
+    return_type = ColumnSchema(
+        logical_type=Ordinal(order=list(range(1, 54))), semantic_tags={"category"}
+    )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the week of the year of {}"
 
     def get_function(self):
         def week(vals):
-            warnings.filterwarnings("ignore",
-                                    message=("Series.dt.weekofyear and Series.dt.week "
-                                             "have been deprecated."),
-                                    module="featuretools"
-                                    )
+            warnings.filterwarnings(
+                "ignore",
+                message=(
+                    "Series.dt.weekofyear and Series.dt.week " "have been deprecated."
+                ),
+                module="featuretools",
+            )
             return vals.dt.week
+
         return week
 
 
@@ -456,15 +504,19 @@ class Weekday(TransformPrimitive):
         >>> weekday(dates).tolist()
         [4, 0, 5]
     """
+
     name = "weekday"
     input_types = [ColumnSchema(logical_type=Datetime)]
-    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(7))), semantic_tags={'category'})
+    return_type = ColumnSchema(
+        logical_type=Ordinal(order=list(range(7))), semantic_tags={"category"}
+    )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the day of the week of {}"
 
     def get_function(self):
         def weekday(vals):
             return vals.dt.weekday
+
         return weekday
 
 
@@ -480,15 +532,19 @@ class Year(TransformPrimitive):
         >>> year(dates).tolist()
         [2019, 2048, 1950]
     """
+
     name = "year"
     input_types = [ColumnSchema(logical_type=Datetime)]
-    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(1, 3000))), semantic_tags={'category'})
+    return_type = ColumnSchema(
+        logical_type=Ordinal(order=list(range(1, 3000))), semantic_tags={"category"}
+    )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the year of {}"
 
     def get_function(self):
         def year(vals):
             return vals.dt.year
+
         return year
 
 
@@ -509,28 +565,33 @@ class IsFederalHoliday(TransformPrimitive):
         ...     datetime(2019, 2, 26)]).tolist()
         [True, False]
     """
+
     name = "is_federal_holiday"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(logical_type=BooleanNullable)
 
-    def __init__(self, country='US'):
+    def __init__(self, country="US"):
         self.country = country
         try:
             self.holidays = holidays.country_holidays(country=self.country)
         except NotImplementedError:
-            available_countries = 'https://github.com/dr-prodigy/python-holidays#available-countries'
-            error = 'must be one of the available countries:\n%s' % available_countries
+            available_countries = (
+                "https://github.com/dr-prodigy/python-holidays#available-countries"
+            )
+            error = "must be one of the available countries:\n%s" % available_countries
             raise ValueError(error)
         years_list = [1950 + x for x in range(150)]
         self.federal_holidays = getattr(holidays, country)(years=years_list)
 
     def get_function(self):
         def is_federal_holiday(x):
-            holidays_df = pd.DataFrame(sorted(self.federal_holidays.items()),
-                                       columns=['dates', 'names'])
+            holidays_df = pd.DataFrame(
+                sorted(self.federal_holidays.items()), columns=["dates", "names"]
+            )
             is_holiday = x.dt.normalize().isin(holidays_df.dates)
             if x.isnull().values.any():
-                is_holiday = is_holiday.astype('object')
+                is_holiday = is_holiday.astype("object")
                 is_holiday[x.isnull()] = np.nan
             return is_holiday.values
+
         return is_federal_holiday
