@@ -9,14 +9,23 @@ import pkg_resources
 
 import featuretools
 
-deps = ["numpy", "pandas", "tqdm", "cloudpickle",
-        "dask", "distributed", "psutil", "Click",
-        "pip", "setuptools"]
+deps = [
+    "numpy",
+    "pandas",
+    "tqdm",
+    "cloudpickle",
+    "dask",
+    "distributed",
+    "psutil",
+    "Click",
+    "pip",
+    "setuptools",
+]
 
 
 def show_info():
     res = subprocess.run(["featuretools", "info"], stdout=subprocess.PIPE)
-    print(res.stdout.decode('utf-8'))
+    print(res.stdout.decode("utf-8"))
 
 
 def print_info():
@@ -56,20 +65,21 @@ def get_sys_info():
     blob = []
 
     try:
-        (sysname, nodename, release,
-         version, machine, processor) = platform.uname()
-        blob.extend([
-            ("python", '.'.join(map(str, sys.version_info))),
-            ("python-bits", struct.calcsize("P") * 8),
-            ("OS", "{sysname}".format(sysname=sysname)),
-            ("OS-release", "{release}".format(release=release)),
-            ("machine", "{machine}".format(machine=machine)),
-            ("processor", "{processor}".format(processor=processor)),
-            ("byteorder", "{byteorder}".format(byteorder=sys.byteorder)),
-            ("LC_ALL", "{lc}".format(lc=os.environ.get('LC_ALL', "None"))),
-            ("LANG", "{lang}".format(lang=os.environ.get('LANG', "None"))),
-            ("LOCALE", '.'.join(map(str, locale.getlocale()))),
-        ])
+        (sysname, nodename, release, version, machine, processor) = platform.uname()
+        blob.extend(
+            [
+                ("python", ".".join(map(str, sys.version_info))),
+                ("python-bits", struct.calcsize("P") * 8),
+                ("OS", "{sysname}".format(sysname=sysname)),
+                ("OS-release", "{release}".format(release=release)),
+                ("machine", "{machine}".format(machine=machine)),
+                ("processor", "{processor}".format(processor=processor)),
+                ("byteorder", "{byteorder}".format(byteorder=sys.byteorder)),
+                ("LC_ALL", "{lc}".format(lc=os.environ.get("LC_ALL", "None"))),
+                ("LANG", "{lang}".format(lang=os.environ.get("LANG", "None"))),
+                ("LOCALE", ".".join(map(str, locale.getlocale()))),
+            ]
+        )
     except (KeyError, ValueError):
         pass
 
