@@ -12,11 +12,15 @@ def replace_tuple_columns(pdf):
     return new_df
 
 
-def replace_nan_with_flag(pdf, flag=-1.):
+def replace_nan_with_flag(pdf, flag=-1.0):
     new_df = pd.DataFrame()
     for c in pdf.columns:
         if isinstance(pdf[c].iloc[0], list):
-            new_df[c] = pdf[c].map(lambda l: [flag if np.isnan(x) else x for x in l] if isinstance(l, (tuple, list)) else l)
+            new_df[c] = pdf[c].map(
+                lambda l: [flag if np.isnan(x) else x for x in l]
+                if isinstance(l, (tuple, list))
+                else l
+            )
         else:
             new_df[c] = pdf[c]
     return new_df
@@ -26,8 +30,8 @@ def replace_categorical_columns(pdf):
     new_df = pd.DataFrame()
     for c in pdf.columns:
         col = pdf[c]
-        if col.dtype.name == 'category':
-            new_df[c] = col.astype('string')
+        if col.dtype.name == "category":
+            new_df[c] = col.astype("string")
         else:
             new_df[c] = pdf[c]
     return new_df
